@@ -1,24 +1,37 @@
 package Mojolicious::Plugin::Libravatar;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '1.01';
+our $VERSION = '1.04';
 
 use Libravatar::URL;
 use Mojo::Cache;
+#use Smart::Comments;
 
 sub register {
     my ( $self, $app, $conf ) = @_;
 
     $conf           //= {};
     $conf->{size}   //= 80;
+    $conf->{rating} //= 'PG';
+    $conf->{cached_email} //= 'user@info.com';
     my $mojo_cache = $conf->{mojo_cache};
     delete $conf->{mojo_cache} if defined $mojo_cache;
     my $cache;
+    ### mojo cache : $mojo_cache
     $cache = Mojo::Cache->new if $mojo_cache;
 
+    $app->helper(
+        cached_avatar => sub {
+            my ( $c, $email, %options ) = @_;
+            my $url = $cache->get($email);
+            return $url if $url;
+            return $app->libravatar_url($conf->{cached_email},%options);
+        },
+    );
     $app->helper(
         libravatar_url => sub {
             my ( $c, $email, %options ) = @_;
+            ### cache : $cache
             return libravatar_url( email => $email, %{$conf}, %options )
               if not defined $cache;
 
@@ -28,10 +41,10 @@ sub register {
                 $cache->set( $email => $url );
             }
             return $url;
-        }
+        },
     );
-}
 
+}
 
 "Donuts. Is there anything they can't do?"
 
@@ -49,7 +62,7 @@ Mojolicious::Plugin::Libravatar - Access the Libravatar API in Mojolicious.
         {
             size       => 30,
             https      => 1,
-            mojo_cache => 1, # optional to enable caching
+            mojo_cache => 1, # optional to enable cacheing
         }
         );
 
@@ -88,6 +101,11 @@ However, one additional parameter has been added:
 This is a boolean parameter (0|1) which, when I<true>, tells the plugin to
 store urls in a cache. For now, this is done with L<Mojo::Cache>.
 
+=head2 cached_email
+
+Default email to use for L<cached_avatar> helper.
+
+
 =head1 HELPERS
 
 =head2 libravatar_url
@@ -101,6 +119,13 @@ Given an email, returns a url for the corresponding avatar. Options
     # Template
     % my $url = libravatar_url 'user@info.com', size => 80,...;
 
+=head2 cached_avatar
+
+If libravatar url for specific email not already cached, return a precached
+default. This might be handy if you don't want to query for avatars at certain
+times
+
+    % my $url = cached_avatar 'xyz@abc.com', https => 1, size => 80 ..;
 
 =head1 SEE ALSO
 
